@@ -18,10 +18,6 @@ from graphrag.api.query import (
     global_search_streaming,
     local_search,
     local_search_streaming,
-    multi_index_basic_search,
-    multi_index_drift_search,
-    multi_index_global_search,
-    multi_index_local_search,
 )
 from graphrag.prompt_tune.types import DocSelectionType
 
@@ -37,10 +33,6 @@ __all__ = [  # noqa: RUF022
     "drift_search_streaming",
     "basic_search",
     "basic_search_streaming",
-    "multi_index_basic_search",
-    "multi_index_drift_search",
-    "multi_index_global_search",
-    "multi_index_local_search",
     # prompt tuning API
     "DocSelectionType",
     "generate_indexing_prompts",
