@@ -33,24 +33,6 @@ class AzureApiVersionMissingError(ValueError):
         super().__init__(msg)
 
 
-class AzureDeploymentNameMissingError(ValueError):
-    """Azure Deployment Name missing error."""
-
-    def __init__(self, llm_type: str) -> None:
-        """Init method definition."""
-        msg = f"Deployment name is required for {llm_type}. Please rerun `graphrag init` set the deployment_name."
-        super().__init__(msg)
-
-
-class LanguageModelConfigMissingError(ValueError):
-    """Missing model configuration error."""
-
-    def __init__(self, key: str = "") -> None:
-        """Init method definition."""
-        msg = f'A {key} model configuration is required. Please rerun `graphrag init` and set models["{key}"] in settings.yaml.'
-        super().__init__(msg)
-
-
 class ConflictingSettingsError(ValueError):
     """Missing model configuration error."""
 
