@@ -15,9 +15,9 @@ class BasicSearchConfig(BaseModel):
         description="The basic search prompt to use.",
         default=graphrag_config_defaults.basic_search.prompt,
     )
-    chat_model_id: str = Field(
+    completion_model_id: str = Field(
         description="The model ID to use for basic search.",
-        default=graphrag_config_defaults.basic_search.chat_model_id,
+        default=graphrag_config_defaults.basic_search.completion_model_id,
     )
     embedding_model_id: str = Field(
         description="The model ID to use for text embeddings.",
