@@ -12,7 +12,7 @@ from graphrag.config.enums import ReportingType
 class ReportingConfig(BaseModel):
     """The default configuration section for Reporting."""
 
-    type: ReportingType = Field(
+    type: ReportingType | str = Field(
         description="The reporting type to use.",
         default=graphrag_config_defaults.reporting.type,
     )
@@ -28,7 +28,7 @@ class ReportingConfig(BaseModel):
         description="The reporting container name to use.",
         default=graphrag_config_defaults.reporting.container_name,
     )
-    storage_account_blob_url: str | None = Field(
+    account_url: str | None = Field(
         description="The storage account blob url to use.",
         default=graphrag_config_defaults.reporting.storage_account_blob_url,
     )
