@@ -2,21 +2,25 @@
 
 # Copyright (c) 2024 Microsoft Corporation.
 # Licensed under the MIT License
+from typing import TYPE_CHECKING
 
-from graphrag.language_model.protocol.base import ChatModel
 from graphrag.prompt_tune.prompt.community_report_rating import (
     GENERATE_REPORT_RATING_PROMPT,
 )
 
+if TYPE_CHECKING:
+    from graphrag_llm.completion import LLMCompletion
+    from graphrag_llm.types import LLMCompletionResponse
+
 
 async def generate_community_report_rating(
-    model: ChatModel, domain: str, persona: str, docs: str | list[str]
+    model: "LLMCompletion", domain: str, persona: str, docs: str | list[str]
 ) -> str:
     """Generate an LLM persona to use for GraphRAG prompts.
 
     Parameters
     ----------
-    - llm (CompletionLLM): The LLM to use for generation
+    - model (LLMCompletion): The LLM to use for generation
     - domain (str): The domain to generate a rating for
     - persona (str): The persona to generate a rating for for
     - docs (str | list[str]): Documents used to contextualize the rating
@@ -30,6 +34,8 @@ async def generate_community_report_rating(
         domain=domain, persona=persona, input_text=docs_str
     )
 
-    response = await model.achat(domain_prompt)
+    response: LLMCompletionResponse = await model.completion_async(
+        messages=domain_prompt
+    )  # type: ignore
 
-    return str(response.output.content).strip()
+    return response.content
