@@ -3,25 +3,32 @@
 
 """Persona generating module for fine-tuning GraphRAG prompts."""
 
-from graphrag.language_model.protocol.base import ChatModel
+from typing import TYPE_CHECKING
+
 from graphrag.prompt_tune.defaults import DEFAULT_TASK
 from graphrag.prompt_tune.prompt.persona import GENERATE_PERSONA_PROMPT
 
+if TYPE_CHECKING:
+    from graphrag_llm.completion import LLMCompletion
+    from graphrag_llm.types import LLMCompletionResponse
+
 
 async def generate_persona(
-    model: ChatModel, domain: str, task: str = DEFAULT_TASK
+    model: "LLMCompletion", domain: str, task: str = DEFAULT_TASK
 ) -> str:
     """Generate an LLM persona to use for GraphRAG prompts.
 
     Parameters
     ----------
-    - llm (CompletionLLM): The LLM to use for generation
+    - model (LLMCompletion): The LLM to use for generation
     - domain (str): The domain to generate a persona for
     - task (str): The task to generate a persona for. Default is DEFAULT_TASK
     """
     formatted_task = task.format(domain=domain)
     persona_prompt = GENERATE_PERSONA_PROMPT.format(sample_task=formatted_task)
 
-    response = await model.achat(persona_prompt)
+    response: LLMCompletionResponse = await model.completion_async(
+        messages=persona_prompt
+    )  # type: ignore
 
-    return str(response.output.content)
+    return response.content
