@@ -5,20 +5,19 @@
 
 import logging
 import time
-from collections.abc import AsyncGenerator
-from typing import Any
+from collections.abc import AsyncGenerator, AsyncIterator
+from typing import TYPE_CHECKING, Any
 
-import tiktoken
+from graphrag_llm.tokenizer import Tokenizer
+from graphrag_llm.utils import (
+    CompletionMessagesBuilder,
+    gather_completion_response_async,
+)
 from tqdm.asyncio import tqdm_asyncio
 
 from graphrag.callbacks.query_callbacks import QueryCallbacks
-from graphrag.language_model.protocol.base import ChatModel
-from graphrag.language_model.providers.fnllm.utils import (
-    get_openai_model_parameters_from_dict,
-)
 from graphrag.query.context_builder.conversation_history import ConversationHistory
 from graphrag.query.context_builder.entity_extraction import EntityVectorStoreKey
-from graphrag.query.llm.text_utils import num_tokens
 from graphrag.query.structured_search.base import BaseSearch, SearchResult
 from graphrag.query.structured_search.drift_search.action import DriftAction
 from graphrag.query.structured_search.drift_search.drift_context import (
@@ -28,6 +27,10 @@ from graphrag.query.structured_search.drift_search.primer import DRIFTPrimer
 from graphrag.query.structured_search.drift_search.state import QueryState
 from graphrag.query.structured_search.local_search.search import LocalSearch
 
+if TYPE_CHECKING:
+    from graphrag_llm.completion import LLMCompletion
+    from graphrag_llm.types import LLMCompletionChunk
+
 logger = logging.getLogger(__name__)
 
 
@@ -36,9 +39,9 @@ class DRIFTSearch(BaseSearch[DRIFTSearchContextBuilder]):
 
     def __init__(
         self,
-        model: ChatModel,
+        model: "LLMCompletion",
         context_builder: DRIFTSearchContextBuilder,
-        token_encoder: tiktoken.Encoding | None = None,
+        tokenizer: Tokenizer | None = None,
         query_state: QueryState | None = None,
         callbacks: list[QueryCallbacks] | None = None,
     ):
@@ -49,18 +52,18 @@ class DRIFTSearch(BaseSearch[DRIFTSearchContextBuilder]):
             llm (ChatOpenAI): The language model used for searching.
             context_builder (DRIFTSearchContextBuilder): Builder for search context.
             config (DRIFTSearchConfig, optional): Configuration settings for DRIFTSearch.
-            token_encoder (tiktoken.Encoding, optional): Token encoder for managing tokens.
+            tokenizer (Tokenizer, optional): Token encoder for managing tokens.
             query_state (QueryState, optional): State of the current search query.
         """
-        super().__init__(model, context_builder, token_encoder)
+        super().__init__(model, context_builder, tokenizer)
 
         self.context_builder = context_builder
-        self.token_encoder = token_encoder
+        self.tokenizer = tokenizer or model.tokenizer
         self.query_state = query_state or QueryState()
         self.primer = DRIFTPrimer(
             config=self.context_builder.config,
             chat_model=model,
-            token_encoder=token_encoder,
+            tokenizer=self.tokenizer,
         )
         self.callbacks = callbacks or []
         self.local_search = self.init_local_search()
@@ -86,21 +89,19 @@ class DRIFTSearch(BaseSearch[DRIFTSearchContextBuilder]):
             "max_context_tokens": self.context_builder.config.local_search_max_data_tokens,
         }
 
-        model_params = get_openai_model_parameters_from_dict({
-            "model": self.model.config.model,
-            "max_tokens": self.context_builder.config.local_search_llm_max_gen_tokens,
+        model_params = {
             "temperature": self.context_builder.config.local_search_temperature,
             "n": self.context_builder.config.local_search_n,
             "top_p": self.context_builder.config.local_search_top_p,
             "max_completion_tokens": self.context_builder.config.local_search_llm_max_gen_completion_tokens,
-            "response_format": {"type": "json_object"},
-        })
+            "response_format_json_object": True,
+        }
 
         return LocalSearch(
             model=self.model,
             system_prompt=self.context_builder.local_system_prompt,
             context_builder=self.context_builder.local_mixed_context,
-            token_encoder=self.token_encoder,
+            tokenizer=self.tokenizer,
             model_params=model_params,
             context_builder_params=local_context_params,
             response_type="multiple paragraphs",
@@ -156,7 +157,11 @@ class DRIFTSearch(BaseSearch[DRIFTSearchContextBuilder]):
         raise ValueError(error_msg)
 
     async def _search_step(
-        self, global_query: str, search_engine: LocalSearch, actions: list[DriftAction]
+        self,
+        global_query: str,
+        k_followups: int,
+        search_engine: LocalSearch,
+        actions: list[DriftAction],
     ) -> list[DriftAction]:
         """
         Perform an asynchronous search step by executing each DriftAction asynchronously.
@@ -171,7 +176,11 @@ class DRIFTSearch(BaseSearch[DRIFTSearchContextBuilder]):
         list[DriftAction]: The results from executing the search actions asynchronously.
         """
         tasks = [
-            action.search(search_engine=search_engine, global_query=global_query)
+            action.search(
+                search_engine=search_engine,
+                global_query=global_query,
+                k_followups=k_followups,
+            )
             for action in actions
         ]
         return await tqdm_asyncio.gather(*tasks, leave=False)
@@ -241,7 +250,10 @@ class DRIFTSearch(BaseSearch[DRIFTSearchContextBuilder]):
             )
             # Process actions
             results = await self._search_step(
-                global_query=query, search_engine=self.local_search, actions=actions
+                global_query=query,
+                k_followups=self.context_builder.config.drift_k_followups,
+                search_engine=self.local_search,
+                actions=actions,
             )
 
             # Update query state
@@ -269,12 +281,10 @@ class DRIFTSearch(BaseSearch[DRIFTSearchContextBuilder]):
             for callback in self.callbacks:
                 callback.on_reduce_response_start(response_state)
 
-            model_params = get_openai_model_parameters_from_dict({
-                "model": self.model.config.model,
-                "max_tokens": self.context_builder.config.reduce_max_tokens,
+            model_params = {
                 "temperature": self.context_builder.config.reduce_temperature,
                 "max_completion_tokens": self.context_builder.config.reduce_max_completion_tokens,
-            })
+            }
 
             reduced_response = await self._reduce_response(
                 responses=response_state,
@@ -320,12 +330,10 @@ class DRIFTSearch(BaseSearch[DRIFTSearchContextBuilder]):
         for callback in self.callbacks:
             callback.on_reduce_response_start(result.response)
 
-        model_params = get_openai_model_parameters_from_dict({
-            "model": self.model.config.model,
-            "max_tokens": self.context_builder.config.reduce_max_tokens,
+        model_params = {
             "temperature": self.context_builder.config.reduce_temperature,
             "max_completion_tokens": self.context_builder.config.reduce_max_completion_tokens,
-        })
+        }
 
         full_response = ""
         async for resp in self._reduce_response_streaming(
@@ -379,23 +387,25 @@ class DRIFTSearch(BaseSearch[DRIFTSearchContextBuilder]):
             context_data=reduce_responses,
             response_type=self.context_builder.response_type,
         )
-        search_messages = [
-            {"role": "system", "content": search_prompt},
-        ]
 
-        model_response = await self.model.achat(
-            prompt=query,
-            history=search_messages,
-            model_parameters=llm_kwargs.get("model_params", {}),
+        messages_builder = (
+            CompletionMessagesBuilder()
+            .add_system_message(search_prompt)
+            .add_user_message(query)
         )
 
-        reduced_response = model_response.output.content
+        model_response = await self.model.completion_async(
+            messages=messages_builder.build(),
+            **llm_kwargs.get("model_params", {}),
+        )
+
+        reduced_response = await gather_completion_response_async(model_response)
 
         llm_calls["reduce"] = 1
-        prompt_tokens["reduce"] = num_tokens(
-            search_prompt, self.token_encoder
-        ) + num_tokens(query, self.token_encoder)
-        output_tokens["reduce"] = num_tokens(reduced_response, self.token_encoder)
+        prompt_tokens["reduce"] = len(self.tokenizer.encode(search_prompt)) + len(
+            self.tokenizer.encode(query)
+        )
+        output_tokens["reduce"] = len(self.tokenizer.encode(reduced_response))
 
         return reduced_response
 
@@ -434,15 +444,21 @@ class DRIFTSearch(BaseSearch[DRIFTSearchContextBuilder]):
             context_data=reduce_responses,
             response_type=self.context_builder.response_type,
         )
-        search_messages = [
-            {"role": "system", "content": search_prompt},
-        ]
 
-        async for response in self.model.achat_stream(
-            prompt=query,
-            history=search_messages,
-            model_parameters=model_params,
-        ):
+        messages_builder = (
+            CompletionMessagesBuilder()
+            .add_system_message(search_prompt)
+            .add_user_message(query)
+        )
+
+        response_search: AsyncIterator[
+            LLMCompletionChunk
+        ] = await self.model.completion_async(
+            messages=messages_builder.build(), stream=True, **model_params
+        )  # type: ignore
+
+        async for chunk in response_search:
+            response_text = chunk.choices[0].delta.content or ""
             for callback in self.callbacks:
-                callback.on_llm_new_token(response)
-            yield response
+                callback.on_llm_new_token(response_text)
+            yield response_text
